@@ -5,10 +5,10 @@ import site
 # import nlp
 
 
-def read_pyspark_model():
+def read_pyspark_model(path):
     # newv = "nltkTransformer-0.0.12/nlp/"
     # return mlflow.spark.load_model(site.getsitepackages()[0] + "/nlp/")
-    return mlflow.spark.load_model("/opt/anaconda3/envs/azurefunc/lib/python3.7/site-packages/nlp" + "")
+    return mlflow.spark.load_model(path)
 
 def read_pyfunc_model():
     # newv = "nltkTransformer-0.0.12/nlp/"
